==> jsmex-trader-sdk-1.1.32.tgz: package/lib/data/TransactionDTO.js <==
const IDTO = global.IDTO || require('./IDTO')
const Joi = global.Joi || require('../../static_dependencies/joi/joi-browser.min.js')
const UID = global.UID || require('../utils/UID')

/**
 * TransactionDTO class
 *
 * @author jsb4ch <jsb4ch@jsmex.io>
 * @since 1.0.0
*/
class TransactionDTO extends IDTO {
  constructor (uid) {
    super(uid)

    this.symbolId = ''
    this.dealId = 0
    this.time = 0
    this.jiuid = 0
    this.side = 0
    this.role = 0
    this.value = ''
    this.price = ''
    this.deal = ''
    this.makerFee = '0'
    this.takerFee = '0'
    this.orderId = 0
  }

  /**
   * TransactionDTO get symbol
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.69
  */
  get symbol () {
    return this.symbolId
  }

  /**
   * TransactionDTO set symbol
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.69
  */
  set symbol (symbolId) {
    this.symbolId = symbolId
  }

  /**
   * TransactionDTO validation method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.0
  */
  validate () {
    const data = {
      symbolId: this.symbolId,
      dealId: this.dealId,
      time: this.time,
      jiuid: this.jiuid,
      side: this.side,
      role: this.role,
      value: this.value,
      price: this.price,
      deal: this.deal,
      makerFee: this.makerFee,
      takerFee: this.takerFee,
      orderId: this.orderId
    }
    const joiValidDepth = Joi.object()
      .keys({
        symbolId: Joi.string().required(),
        dealId: Joi.number(),
        orderId: Joi.number(),
        jiuid: Joi.number(),
        time: Joi.number().required(),
        side: Joi.alternatives().try(
          Joi.string().valid('ask', 'bid', '1', '2'),
          Joi.number().valid(0, 1, 2)
        ),
        role: Joi.alternatives().try(
          Joi.string().valid('maker', 'taker', '1', '2'),
          Joi.number().valid(0, 1, 2)
        ),
        price: Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50).required(),
        value: Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50).required(),
        deal: Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50).required(),
        makerFee: Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50),
        takerFee: Joi.string().regex(/^\d+\.\d+$|^\d+$/).min(1).max(50),
        label: Joi.alternatives().try(
          Joi.string(),
          Joi.string().valid('')
        )
      })

    const result = Joi.validate(data, joiValidDepth)
    if (result.error) {
      throw result.error
    }
    return result.value
  }

  /**
   * TransactionDTO toObject method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.14
   * @returns {Object}
  */
  toObject () {
    return {
      uid: this.uid,
      symbolId: this.symbolId,
      dealId: this.dealId,
      time: this.time,
      jiuid: this.jiuid,
      side: this.side ? this.side : undefined,
      role: this.role ? this.role : undefined,
      value: this.value,
      price: this.price,
      deal: this.deal,
      makerFee: this.makerFee,
      takerFee: this.takerFee,
      orderId: this.orderId
    }
  }

  /**
   * TransactionDTO fromObject method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.14
   * @param objectData object
   * @returns TransactionDTO
  */
  static fromObject (objectData) {
    const transactionDTO = new TransactionDTO(UID.create())
    transactionDTO.symbolId = objectData.symbolId
    transactionDTO.dealId = objectData.dealId
    transactionDTO.time = objectData.time
    transactionDTO.jiuid = objectData.jiuid
    transactionDTO.side = objectData.side || 0
    transactionDTO.role = objectData.role || 0
    transactionDTO.value = objectData.value
    transactionDTO.price = objectData.price
    transactionDTO.deal = objectData.deal
    transactionDTO.makerFee = objectData.makerFee
    transactionDTO.takerFee = objectData.takerFee
    transactionDTO.orderId = objectData.orderId
    transactionDTO.validate()
    return transactionDTO
  }
}

module.exports = TransactionDTO

==> jsmex-trader-sdk-1.1.50.tgz: package/lib/data/TransactionDTO.js <==
const IDTO = global.IDTO || require('./IDTO')
const Joi = global.Joi || require('../../static_dependencies/joi/joi-browser.min.js')
const UID = global.UID || require('../utils/UID')

/**
 * TransactionDTO class
 *
 * @author jsb4ch <jsb4ch@jsmex.io>
 * @since 1.0.0
*/
class TransactionDTO extends IDTO {
  constructor (uid) {
    super(uid)

    this.symbolId = ''
    this.dealId = 0
    this.time = 0
    this.jiuid = 0
    this.side = 0
    this.role = 0
    this.value = ''
    this.price = ''
    this.deal = ''
    this.makerFee = '0'
    this.takerFee = '0'
    this.orderId = 0
  }

  /**
   * TransactionDTO get symbol
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.69
  */
  get symbol () {
    return this.symbolId
  }

  /**
   * TransactionDTO set symbol
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.69
  */
  set symbol (symbolId) {
    this.symbolId = symbolId
  }

  /**
   * TransactionDTO validation method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.0
  */
  validate () {
    const data = {
      symbolId: this.symbolId,
      dealId: this.dealId,
      time: this.time,
      jiuid: this.jiuid,
      side: this.side,
      role: this.role,
      value: this.value,
      price: this.price,
      deal: this.deal,
      makerFee: this.makerFee,
      takerFee: this.takerFee,
      orderId: this.orderId
    }
    const joiValidDepth = Joi.object()
      .keys({
        symbolId: Joi.string().required(),
        dealId: Joi.number(),
        orderId: Joi.number(),
        jiuid: Joi.number(),
        time: Joi.number().required(),
        side: Joi.alternatives().try(
          Joi.string().valid('ask', 'bid', '1', '2'),
          Joi.number().valid(0, 1, 2)
        ),
        role: Joi.alternatives().try(
          Joi.string().valid('maker', 'taker', '1', '2'),
          Joi.number().valid(0, 1, 2)
        ),
        price: Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50).required(),
        value: Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50).required(),
        deal: Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50).required(),
        makerFee: Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50),
        takerFee: Joi.string().regex(/^\d+\.\d+$|^\d+\.\d+e-\d+$|^\d+$|^\d+e-\d+$/).min(1).max(50),
        label: Joi.alternatives().try(
          Joi.string(),
          Joi.string().valid('')
        )
      })

    const result = Joi.validate(data, joiValidDepth)
    if (result.error) {
      throw result.error
    }
    return result.value
  }

  /**
   * TransactionDTO toObject method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.14
   * @returns {Object}
  */
  toObject () {
    return {
      uid: this.uid,
      symbolId: this.symbolId,
      dealId: this.dealId,
      time: this.time,
      jiuid: this.jiuid,
      side: this.side ? this.side : undefined,
      role: this.role ? this.role : undefined,
      value: this.value,
      price: this.price,
      deal: this.deal,
      makerFee: this.makerFee,
      takerFee: this.takerFee,
      orderId: this.orderId
    }
  }

  /**
   * TransactionDTO fromObject method
   *
   * @author jsb4ch <jsb4ch@jsmex.io>
   * @since 1.0.14
   * @param objectData object
   * @returns TransactionDTO
  */
  static fromObject (objectData) {
    const transactionDTO = new TransactionDTO(UID.create())
    transactionDTO.symbolId = objectData.symbolId
    transactionDTO.dealId = objectData.dealId
    transactionDTO.time = objectData.time
    transactionDTO.jiuid = objectData.jiuid
    transactionDTO.side = objectData.side || 0
    transactionDTO.role = objectData.role || 0
    transactionDTO.value = objectData.value
    transactionDTO.price = objectData.price
    transactionDTO.deal = objectData.deal
    transactionDTO.makerFee = objectData.makerFee
    transactionDTO.takerFee = objectData.takerFee
    transactionDTO.orderId = objectData.orderId
    transactionDTO.validate()
    return transactionDTO
  }
}

module.exports = TransactionDTO
